@@ -16,7 +16,7 @@ from urllib.parse import urljoin
 
 import lazy_import
 import pyperclip
-import ujson
+import json
 
 jsonpickle = lazy_import.lazy_module("jsonpickle")
 import regex as re
@@ -51,7 +51,7 @@ class ChepyDecorators(object):
 
 
 class ChepyCore(object):
-    """The `ChepyCore` class for Chepy is primarily used as an interface
+    """The ChepyCore class for Chepy is primarily used as an interface
     for all the current modules/classes in Chepy, or for plugin development.
     The `ChepyCore` class is what provides the various attributes like **states**,
     **buffers**, etc and is required to use and extend Chepy.
@@ -130,7 +130,7 @@ class ChepyCore(object):
         Returns:
             Any: unpickeled JSON as a python object.
         """
-        return ujson.loads(jsonpickle.encode(obj, unpicklable=True))
+        return json.loads(jsonpickle.encode(obj, unpicklable=True))
 
     def _load_as_file(self) -> object:
         """This method is used when a function or a method expects
@@ -231,6 +231,53 @@ class ChepyCore(object):
                     self.states[i] = getattr(self, method_name)().o
         return self
 
+    def for_each(self, methods: List[Tuple[Union[str, object], dict]]):
+        """Run multiple methods on current state if it is a list
+
+        Method names in a list of tuples. If using in the cli,
+        this should not contain any spaces.
+
+        Args:
+            methods (List[Tuple[Union[str, object], dict]]): Required.
+                List of tuples
+
+        Returns:
+            Chepy: The Chepy object.
+
+        Examples:
+            This method takes an array of method names and their args as an list of
+            tuples; the first value of the tuple is the method name as either a string,
+            or as an object, and the second value is a ditionary of arguments. The keys of
+            in the dictionary are method argument names, while the values are argument
+            values.
+
+            >>> from chepy import Chepy
+            >>> c = Chepy(['41', '42'])
+            >>> c.for_each([("from_hex",), ("to_hex",)])
+            >>> # this is how to use fork methods with a string
+            >>> c.for([(c.from_hex,), (c.to_hex,)])
+            >>> # This is how to use fork using methods
+            >>> print(c)
+            ['41', '42']
+        """
+        assert isinstance(self.state, list), "Current state is not a list"
+        hold = self.state
+        for i, val in enumerate(hold):
+            self.state = val
+            for method in methods:
+                if type(method[0]).__name__ == "method":
+                    method_name = method[0].__name__  # pragma: no cover
+                elif isinstance(method[0], str):
+                    method_name = method[0]
+                if len(method) > 1:
+                    hold[i] = getattr(self, method_name)(
+                        **method[1]
+                    ).o  # pragma: no cover
+                else:
+                    hold[i] = getattr(self, method_name)().o
+        self.state = hold
+        return self
+
     @ChepyDecorators.call_stack
     def set_state(self, data: Any):
         """Set any arbitrary values in the current state
@@ -910,7 +957,7 @@ class ChepyCore(object):
             NzM2ZjZkNjUyMDY0NjE3NDYx
         """
         with self._abs_path(path) as f:
-            f.write_text(ujson.dumps(self._stack))
+            f.write_text(json.dumps(self._stack))
         self._info_logger("Saved recipe to {}".format(str(path)))
         return self
 
@@ -928,7 +975,7 @@ class ChepyCore(object):
             NzM2ZjZkNjUyMDY0NjE3NDYx
         """
         with self._abs_path(path) as f:
-            recipes = ujson.loads(f.read_text())
+            recipes = json.loads(f.read_text())
             for recipe in recipes:
                 function = recipe["function"]
                 args = recipe["args"]
@@ -1030,7 +1077,7 @@ class ChepyCore(object):
             )
         )
         if isinstance(args, str):  # pragma: no cover
-            args = ujson.loads(args)
+            args = json.loads(args)
         try:
             for index, data in enumerate(current_state):
                 self.state = current_state[index]
@@ -1087,10 +1134,10 @@ class ChepyCore(object):
         )
 
         if isinstance(keys, str):  # pragma: no cover
-            keys = ujson.loads(keys)
+            keys = json.loads(keys)
 
         if isinstance(args, str):  # pragma: no cover
-            args = ujson.loads(args)
+            args = json.loads(args)
         try:
             dict_keys = current_state.keys()
             for key in keys:
