@@ -4,7 +4,8 @@ import base64
 import codecs
 import html
 import base58
-import ujson
+import json
+from random import randint
 
 yaml = lazy_import.lazy_module("yaml")
 import regex as re
@@ -76,7 +77,7 @@ class DataFormat(ChepyCore):
             >>> Chepy("[1,2,'lol', true]").str_list_to_list().o
             [1, 2, "lol", True]
         """
-        self.state = ujson.loads(re.sub(r"'", '"', self._convert_to_str()))
+        self.state = json.loads(re.sub(r"'", '"', self._convert_to_str()))
         return self
 
     @ChepyDecorators.call_stack
@@ -125,7 +126,7 @@ class DataFormat(ChepyCore):
                 "a": ["list", 1, True],
             }
         """
-        self.state = ujson.loads(self._convert_to_str())
+        self.state = json.loads(self._convert_to_str())
         return self
 
     @ChepyDecorators.call_stack
@@ -140,7 +141,7 @@ class DataFormat(ChepyCore):
             '{"some":"data","a":["list",1,true]}'
         """
         assert isinstance(self.state, dict), "Not a dict object"
-        self.state = ujson.dumps(self.state)
+        self.state = json.dumps(self.state)
         return self
 
     @ChepyDecorators.call_stack
@@ -150,7 +151,7 @@ class DataFormat(ChepyCore):
         Returns:
             Chepy: The Chepy object.
         """
-        self.state = ujson.dumps(yaml.safe_load(self.state))
+        self.state = json.dumps(yaml.safe_load(self.state))
         return self
 
     @ChepyDecorators.call_stack
@@ -166,7 +167,7 @@ class DataFormat(ChepyCore):
                 return super(ChepyYamlDumper, self).increase_indent(flow, False)
 
         self.state = yaml.dump(
-            ujson.loads(self.state),
+            json.loads(self.state),
             Dumper=ChepyYamlDumper,
             default_flow_style=False,
             sort_keys=False,
@@ -1068,3 +1069,85 @@ class DataFormat(ChepyCore):
                 hold.append(d)
         self.state = join_by.join(hold)
         return self
+
+    @ChepyDecorators.call_stack
+    def swap_strings(self, by: int) -> DataFormatT:
+        """Swap characters in string
+
+        Args:
+            by (int): Number of bytes to swap
+
+        Returns:
+            Chepy: The Chepy object
+        """
+        t = list(self.state)
+        t[::by], t[1::by] = t[1::by], t[::by]
+        self.state = "".join(t)
+        return self
+
+    @ChepyDecorators.call_stack
+    def to_string(self) -> DataFormatT:
+        """Convert to string
+
+        Returns:
+            Chepy: The Chepy object
+        """
+        self.state = self._convert_to_str()
+        return self
+
+    @ChepyDecorators.call_stack
+    def select(self, start: int, end: int = None) -> DataFormatT:
+        """Get an item by specifying an index
+
+        Args:
+            start (int): Starting index number to get
+            end (int, optional): Ending index number to get. If none specified, will be end of item. Defaults to None.
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        if end is None:
+            self.state = self.state[start:]
+        else:
+            self.state = self.state[start:end]
+        return self
+
+    @ChepyDecorators.call_stack
+    def length(self) -> DataFormatT:
+        """Get the length of the current state as string
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        self.state = len(self.state)
+        return self
+
+    @ChepyDecorators.call_stack
+    def to_leetcode(self, replace_space: str = "") -> DataFormatT:
+        """Convert to leetcode. Reference
+        Reference github.com/ss8651twtw/CTF-flag-generator
+
+        Args:
+            replace_space (str, optional): Replace spaces with specified char. Defaults to ''.
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+
+        def change(c):
+            if replace_space and c == " ":
+                return replace_space
+            if c.isalpha():
+                c = c.upper()
+                char_set = Encoding.LEETCODE[ord(c) - ord("A")]
+                new_c = char_set[randint(0, len(char_set) - 1)]
+                return new_c
+            else:
+                return c
+
+        hold = ""
+        string = self._convert_to_str()
+        for s in string:
+            hold += change(s)
+        self.state = hold
+        return self
