@@ -3,7 +3,7 @@ import binascii
 import codecs
 import itertools
 import string
-from typing import TypeVar
+from typing import Literal, TypeVar
 
 import lazy_import
 
@@ -12,7 +12,7 @@ import pathlib
 
 import pycipher
 import regex as re
-import ujson
+import json
 
 AES = lazy_import.lazy_module("Crypto.Cipher.AES")
 ARC4 = lazy_import.lazy_module("Crypto.Cipher.ARC4")
@@ -159,7 +159,7 @@ class EncryptionEncoding(ChepyCore):
 
     @ChepyDecorators.call_stack
     def xor(
-        self, key: str, key_type: str = "hex", ascii: bool = False
+        self, key: str, key_type: Literal['hex', 'utf', 'base64'] = "hex", ascii: bool = False
     ) -> EncryptionEncodingT:
         """XOR state with a key
 
@@ -297,7 +297,7 @@ class EncryptionEncoding(ChepyCore):
         if isinstance(self.state, dict):
             data = self.state
         elif isinstance(self.state, str):
-            data = ujson.loads(self.state)
+            data = json.loads(self.state)
         self.state = jwt.encode(data, key=secret, algorithm=algorithms)
         return self
 
