@@ -1,26 +1,30 @@
 import io
-from typing import List, Tuple
-from PIL import Image, ImageFilter, ImageOps, ImageDraw, ImageEnhance
+from typing import List, Tuple, TypeVar
+
+from PIL import Image, ImageDraw, ImageEnhance, ImageFilter, ImageOps
+
 from ..core import ChepyCore, ChepyDecorators
 
+MultimediaT = TypeVar("MultimediaT", bound="Multimedia")
+
 
 class Multimedia(ChepyCore):
-    """The `Multimedia` class is used predominantly to handle image and 
-    audio file processing. All the methods within the `Multimedia` class 
-    are available in the main **Chepy** class. For coverage, it is important 
-    to understand that this class will sometimes coerce non RGBA to RGB and 
+    """The `Multimedia` class is used predominantly to handle image and
+    audio file processing. All the methods within the `Multimedia` class
+    are available in the main **Chepy** class. For coverage, it is important
+    to understand that this class will sometimes coerce non RGBA to RGB and
     RGB to RGBA formats.
-    
+
     Examples:
         To use the Multimedia class as a standalone, import with
-        
+
         >>> from chepy.modules.multimedia import Multimedia
         >>> m = Multimedia("/path/to/image.png").load_file()
         This will load the image as bytes into Chepy.
 
-        Advanced example using the Multimedia class. We will take 
-        our loaded image, convert it split out the RGB color channels, 
-        get the blue image, blur it and finally write it to disk. 
+        Advanced example using the Multimedia class. We will take
+        our loaded image, convert it split out the RGB color channels,
+        get the blue image, blur it and finally write it to disk.
 
         >>> from chepy.modules.multimedia import Multimedia
         >>> m = Multimedia("/path/to/image.png").load_file()
@@ -62,18 +66,18 @@ class Multimedia(ChepyCore):
         extension: str = "png",
         resample: str = "nearest",
         quality: int = 100,
-    ):
-        """Resize an image. 
-        
+    ) -> MultimediaT:
+        """Resize an image.
+
         Args:
             width (int): Required. Width in pixels
             height (int): Required. Height in pixels
             extension (str, optional): File extension of loaded image. Defaults to png
             resample (str, optional): Resample rate. Defaults to "nearest".
             quality (int, optional): Quality of output. Defaults to 100.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("image.png").load_file().resize_image(256, 256, "png")
@@ -101,14 +105,14 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def split_color_channels(self, extension: str = "png"):
+    def split_color_channels(self, extension: str = "png") -> MultimediaT:
         """Split an image into its red, green and blue channels
 
         Args:
             extension (str, optional): File extension of loaded image. Defaults to png
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             Write the blue image to disk in this example
@@ -150,15 +154,15 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def rotate_image(self, rotate_by: int, extension: str = "png"):
+    def rotate_image(self, rotate_by: int, extension: str = "png") -> MultimediaT:
         """Rotate an image
-        
+
         Args:
             rotate_by (int): Required. Roate by degrees
             extension (str, optional): File extension of loaded image. Defaults to png
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             To flip an image horizontally, we can:
@@ -176,16 +180,16 @@ class Multimedia(ChepyCore):
     @ChepyDecorators.call_stack
     def blur_image(
         self, extension: str = "png", gaussian: bool = False, radius: int = 2
-    ):
+    ) -> MultimediaT:
         """Blur an image
-        
+
         Args:
             extension (str, optional): File extension of loaded image. Defaults to png
             gaussian (bool, optional): If Gaussian blur is to be applied. Defaults to False.
             radius (int, optional): Radius for Gaussian blur. Defaults to 2.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("logo.png").load_file().blur_image("png")
@@ -208,14 +212,14 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def grayscale_image(self, extension: str = "png"):
+    def grayscale_image(self, extension: str = "png") -> MultimediaT:
         """Grayscale an image
-        
+
         Args:
             extension (str, optional): File extension of loaded image. Defaults to png
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("logo.png").load_file().grayscale_image("png")
@@ -229,14 +233,14 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def invert_image(self, extension: str = "png"):
+    def invert_image(self, extension: str = "png") -> MultimediaT:
         """Invert the colors of the image
-        
+
         Args:
             extension (str, optional): File extension of loaded image. Defaults to png
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("logo.png").load_file().invert_image("png")
@@ -251,15 +255,15 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def image_opacity(self, level: int, extension: str = "png"):
+    def image_opacity(self, level: int, extension: str = "png") -> MultimediaT:
         """Change the opacity of an image
-        
+
         Args:
             level (int): Required. Level of opacity. Half is 128
             extension (str, optional): File extension of loaded image. Defaults to png
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         image = Image.open(self._load_as_file())
         image = self._force_rgba(image)
@@ -270,15 +274,15 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def image_contrast(self, factor: int, extension: str = "png"):
+    def image_contrast(self, factor: int, extension: str = "png") -> MultimediaT:
         """Change image contrast
-        
+
         Args:
             factor (int): Factor to increase the contrast by
             extension (str, optional): File extension of loaded image. Defaults to "png"
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         image = Image.open(self._load_as_file())
         image = self._force_rgb(image)
@@ -289,15 +293,15 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def image_brightness(self, factor: int, extension: str = "png"):
+    def image_brightness(self, factor: int, extension: str = "png") -> MultimediaT:
         """Change image brightness
-        
+
         Args:
             factor (int): Factor to increase the brightness by
             extension (str, optional): File extension of loaded image. Defaults to "png"
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         image = Image.open(self._load_as_file())
         image = self._force_rgb(image)
@@ -308,15 +312,15 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def image_sharpness(self, factor: int, extension: str = "png"):
+    def image_sharpness(self, factor: int, extension: str = "png") -> MultimediaT:
         """Change image sharpness
-        
+
         Args:
             factor (int): Factor to increase the sharpness by
             extension (str, optional): File extension of loaded image. Defaults to "png"
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         image = Image.open(self._load_as_file())
         image = self._force_rgb(image)
@@ -327,15 +331,15 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def image_color(self, factor: int, extension: str = "png"):
+    def image_color(self, factor: int, extension: str = "png") -> MultimediaT:
         """Change image color
-        
+
         Args:
             factor (int): Factor to increase the color by
             extension (str, optional): File extension of loaded image. Defaults to "png"
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         image = Image.open(self._load_as_file())
         image = self._force_rgb(image)
@@ -350,18 +354,18 @@ class Multimedia(ChepyCore):
         self,
         art_width: int = 120,
         chars: List[str] = ["B", "S", "#", "&", "@", "$", "%", "*", "!", ":", "."],
-    ):  # pragma: no cover
+    ) -> MultimediaT:  # pragma: no cover
         """Convert image to ascii art
 
         `Reference: <https://dev.to/anuragrana/generating-ascii-art-from-colored-image-using-python-4ace>`__
-        
+
         Args:
-            art_width (int, optional): Width of the ascii art. Higher values 
+            art_width (int, optional): Width of the ascii art. Higher values
                 show more details. Defaults to 120.
             chars (List[str], optional): A list of chars to build the ascii art with
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("pythonlogo.png").load_file()
@@ -423,14 +427,14 @@ class Multimedia(ChepyCore):
         return self
 
     @ChepyDecorators.call_stack
-    def convert_image(self, format_to: str):
-        """Change image format. 
+    def convert_image(self, format_to: str) -> MultimediaT:
+        """Change image format.
 
         Example, convert png to jpeg
-        
+
         Args:
             format_to (str): Required. A valid image format extension
-        
+
         Returns:
             Chepy: The Chepy object
 
@@ -460,19 +464,19 @@ class Multimedia(ChepyCore):
         extension: str = "png",
         coordinates: Tuple[int, int] = (0, 0),
         color: Tuple[int, int, int] = (0, 0, 0),
-    ):
+    ) -> MultimediaT:
         """Add text to an image
-        
+
         Args:
             text (str): Required. Text to add
             extension (str, optional): File extension of loaded image. Defaults to png
-            coordinates (Tuple[int, int], optional): Coordinates of image where to add text. 
+            coordinates (Tuple[int, int], optional): Coordinates of image where to add text.
                 Defaults to (0, 0).
-            color (Tuple[int, int, int], optional): Color of text. 
+            color (Tuple[int, int, int], optional): Color of text.
                 Defaults to (0, 0, 0) which is black.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
 
         Examples:
             >>> c = Chepy("logo.png").load_file().image_add_text("some text")
@@ -495,15 +499,15 @@ class Multimedia(ChepyCore):
     @ChepyDecorators.call_stack
     def lsb_dump_by_channel(
         self, channel: str = "r", column_first: bool = False
-    ):  # pragma: no cover
+    ) -> MultimediaT:  # pragma: no cover
         """Dump LSB from a specific color channel
-        
+
         Args:
             channel (str, optional): Color channel. r, g, b. Defaults to 'r'.
             column_first (bool, optional): Order by column first. Defaults to False.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         channels = ["r", "g", "b"]
         assert channel in channels, "Valid channels are {}".format("".join(channels))
@@ -536,15 +540,15 @@ class Multimedia(ChepyCore):
     @ChepyDecorators.call_stack
     def msb_dump_by_channel(
         self, channel: str = "r", column_first: bool = False
-    ):  # pragma: no cover
+    ) -> MultimediaT:  # pragma: no cover
         """Dump MSB from a specific color channel
-        
+
         Args:
             channel (str, optional): Color channel. r, g, b. Defaults to 'r'.
             column_first (bool, optional): Order by column first. Defaults to False.
-        
+
         Returns:
-            Chepy: The Chepy object. 
+            Chepy: The Chepy object.
         """
         channels = ["r", "g", "b"]
         assert channel in channels, "Valid channels are {}".format("".join(channels))
