@@ -1,9 +1,11 @@
+import lazy_import
 import difflib
 from collections import OrderedDict
 from typing import TypeVar, Union
 
 import chepy.modules.internal.colors as _int_colors
-import exrex
+
+exrex = lazy_import.lazy_module("exrex")
 import pydash
 import regex as re
 
@@ -201,6 +203,16 @@ class Utils(ChepyCore):
         self.state = re.findall(".{1," + str(n) + "}", self._convert_to_str())
         return self
 
+    @ChepyDecorators.call_stack
+    def split_lines(self):
+        """Split a string by newline characters.
+
+        Returns:
+            Chepy: The Chepy object.
+        """
+        self.state = self._convert_to_str().split()
+        return self
+
     @ChepyDecorators.call_stack
     def select_every_n(self, n: int, start: int = 0) -> UtilsT:
         """Select every nth item from a list or string.
